@@ -6,7 +6,10 @@
 import os
 import sys
 
-import tornado.web
+try:
+    import tornado.web
+except ImportError:
+    raise RuntimeError("You need tornado installed to use this worker.")
 from tornado.httpserver import HTTPServer
 from tornado.ioloop import IOLoop, PeriodicCallback
 from tornado.wsgi import WSGIContainer
@@ -15,31 +18,23 @@ from tornado.wsgi import WSGIContainer
 from gunicorn.workers.base import Worker
 from gunicorn import __version__ as gversion
 
-
-def patch_request_handler():
-    web = sys.modules.pop("tornado.web")
-
-    old_clear = web.RequestHandler.clear
-
-    def clear(self):
-        old_clear(self)
-        self._headers["Server"] += " (Gunicorn/%s)" % gversion
-         
-    web.RequestHandler.clear = clear
-    sys.modules["tornado.web"] = web
-    
-
 class TornadoWorker(Worker):
     
     @classmethod
     def setup(cls):
-        patch_request_handler()
+        web = sys.modules.pop("tornado.web")
+        old_clear = web.RequestHandler.clear
+        def clear(self):
+            old_clear(self)
+            self._headers["Server"] += " (Gunicorn/%s)" % gversion
+        web.RequestHandler.clear = clear
+        sys.modules["tornado.web"] = web
         
     def watchdog(self):
         self.notify()
             
         if self.ppid != os.getppid():
-            self.log.info("Parent changed, shutting down: %s" % self)
+            self.log.info("Parent changed, shutting down: %s", self)
             self.ioloop.stop()
     
     def run(self):
